@@ -10,9 +10,12 @@ class ENDPOINTS:
     LOYALTY_URI = f'{BASE_URI}/v1/investor/loyalty'
 
     INVESTMENTS_STATUS_URI = f'{BASE_URI}/v2/investor/overview/investment_statuses/current'
-    PROFILE_URI = f'{BASE_URI}/v1/investor/profile'
     INVESTMENTS_URI = f'{BASE_URI}/v1/investor/investments'
+    INVESTMENTS_AGREEMENT_URI = f'{BASE_URI}/v1/investments'
 
     LOANS_URI = f'{BASE_URI}/v1/loans'
     CASH_FLOW_URI = f'{BASE_URI}/v2/investor/transactions'
     ACCOUNT_SUMMARY_URI = f'{BASE_URI}/v2/investor/account-summary'
+
+    PROFILE_URI = f'{BASE_URI}/v1/investor/profile'
+    GLOBALS_URI = f'{BASE_URI}/v1/globals'
